### MaBoSS_test

[![Documentation Status](https://readthedocs.org/projects/maboss-test/badge/?version=latest)](https://maboss-test.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/maboss-test.svg)](https://badge.fury.io/py/maboss-test)

MaBoSS_test is model testing library for models built with the MaBoSS software. It is based on python unittest standard library, and follow the same coding structure. 


#### Installing

```
pip install maboss_test
python -m maboss_setup 
```

The first command will install the library, the second one will install maboss executables

